@@ -11,6 +11,7 @@ use unittest instead of this tool.
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
+import os
 import sys
 import importlib
 
@@ -27,9 +28,14 @@ def import_attribute(name):
 
 def main():
     """Entry function"""
+    #Make current working directory as the first python module search path
+    sys.path.insert(0, os.getcwd())
+
     func_str = sys.argv[1]
-    sys.argv = sys.argv[1:]
     func = import_attribute(func_str)
+
+    #shfit command line arguments, so func can parse sys.argv properly.
+    sys.argv = sys.argv[1:]
     func()
 
 
